@@ -100,7 +100,7 @@ class CBC(SystemCallSolver):
             return None
         return executable.get_path()
 
-    def create_command_line(self,executable,problem_files):
+    def create_command_line(self, executable, problem_files):
         #
         # Define the log file 
         #
@@ -141,9 +141,6 @@ class CBC(SystemCallSolver):
         #
         # Define command line
         #
-        if (self.mipgap is not None):
-           raise ValueError, "The mipgap parameter is currently not being processed by CBC solver plugin"
-        
         if self._problem_format == ProblemFormat.nl:
             if self._timelimit is not None and self._timelimit > 0.0:
                 timing = " sec="+str(self._timelimit)
@@ -187,7 +184,7 @@ class CBC(SystemCallSolver):
         # Initial values
         #
         soln = results.solution.add()
-        soln.objective['f'].value=float('inf')
+        soln.objective['__default_objective__'].value = float('inf')
         #
         # Process logfile
         #
@@ -230,12 +227,12 @@ class CBC(SystemCallSolver):
              results.problem.sense = ProblemSense.maximize
           if len(tokens) > 3 and tokens[0] == "Presolve" and tokens[6] == "infeasible":
              soln.status = SolutionStatus.infeasible
-             soln.objective['f'].value=None
+             soln.objective['__default_objective__'].value = None
           if len(tokens) > 3 and tokens[0] == "Optimal" and tokens[1] == "objective":
              soln.status = SolutionStatus.optimal
-             soln.objective['f'].value=eval(tokens[2])
+             soln.objective['__default_objective__'].value=eval(tokens[2])
           if len(tokens) > 6 and tokens[4] == "best" and tokens[5] == "objective":
-             soln.objective['f'].value=eval(tokens[6])
+             soln.objective['__default_objective__'].value=eval(tokens[6])
           if len(tokens) > 9 and tokens[7] == "(best" and tokens[8] == "possible":
              results.problem.lower_bound=tokens[9]
              results.problem.lower_bound = eval(results.problem.lower_bound.split(")")[0])
@@ -243,12 +240,12 @@ class CBC(SystemCallSolver):
              results.problem.lower_bound=eval(tokens[12])
           if len(tokens) > 3 and tokens[0] == "Result" and tokens[2] == "Finished":
              soln.status = SolutionStatus.optimal
-             soln.objective['f'].value=eval(tokens[4])
+             soln.objective['__default_objective__'].value=eval(tokens[4])
           if len(tokens) > 10 and tokens[4] == "time" and tokens[9] == "nodes":
              results.solver.statistics.branch_and_bound.number_of_created_subproblems=eval(tokens[8])
              results.solver.statistics.branch_and_bound.number_of_bounded_subproblems=eval(tokens[8])
              if eval(results.solver.statistics.branch_and_bound.number_of_bounded_subproblems) > 0:
-                soln.objective['f'].value=eval(tokens[6])
+                soln.objective['__default_objective__'].value=eval(tokens[6])
           if len(tokens) == 5 and tokens[1] == "Exiting" and tokens[4] == "time":
              soln.status = SolutionStatus.stoppedByLimit
           if len(tokens) > 8 and tokens[7] == "nodes":
@@ -260,23 +257,29 @@ class CBC(SystemCallSolver):
              results.solver.user_time=eval(tokens[1])
           results.solver.user_time=-1.0
 
-        if soln.objective['f'].value == "1e+50":
+        if soln.objective['__default_objective__'].value == "1e+50":
            if results.problem.sense == ProblemSense.minimize:
-              soln.objective['f'].value=float('inf')
+              soln.objective['__default_objective__'].value=float('inf')
            else:
-              soln.objective['f'].value=float('-inf')
+              soln.objective['__default_objective__'].value=float('-inf')
         elif results.problem.sense == ProblemSense.maximize:
-                soln.objective['f'].value *= -1
+                soln.objective['__default_objective__'].value *= -1
         if soln.status is SolutionStatus.optimal:
            soln.gap=0.0
            if results.problem.sense == ProblemSense.minimize:
-                results.problem.lower_bound = soln.objective['f'].value
+                results.problem.lower_bound = soln.objective['__default_objective__'].value
                 if "upper_bound" in dir(results.problem):
                     del results.problem.upper_bound
            else:
-                results.problem.upper_bound = soln.objective['f'].value
+                results.problem.upper_bound = soln.objective['__default_objective__'].value
                 if "lower_bound" in dir(results.problem):
                     del results.problem.lower_bound
+
+        if soln.status == SolutionStatus.optimal:
+            results.solver.termination_condition = TerminationCondition.optimal
+        elif soln.status == SolutionStatus.infeasible:
+            results.solver.termination_condition = TerminationCondition.infeasible
+
         if results.solver.status is SolverStatus.error:
            results.solution.delete(0)
         if results.problem.name is None:
@@ -325,9 +328,9 @@ class CBC(SystemCallSolver):
              if tokens[0] == "Optimal":
                 solution.status = SolutionStatus.optimal
                 solution.gap = 0.0
-                solution.objective['f'].value = eval(tokens[-1])
+                solution.objective['__default_objective__'].value = eval(tokens[-1])
                 if results.problem.sense == ProblemSense.maximize:
-                    solution.objective['f'].value *= -1
+                    solution.objective['__default_objective__'].value *= -1
              elif tokens[0] == "Infeasible":
                 solution.status = SolutionStatus.infeasible
                 solution.gap = None
