@@ -14,7 +14,6 @@ import re
 from coopr.opt.base import *
 from coopr.opt.results import *
 from coopr.opt.solver import *
-from coopr.pyomo.base.var import *
 import mockmip
 import pyutilib.services
 import pyutilib.common
@@ -76,6 +75,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
     def _hasIntegerVariables(self, instance):
 
        import coopr.pyomo.base.var
+       from coopr.pyomo.base import Var
        from coopr.pyomo.base.set_types import IntegerSet, BooleanSet
 
        for variable in instance.active_components(Var).values():
@@ -98,6 +98,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
     def warm_start(self, instance):
 
        import coopr.pyomo.base.var
+       from coopr.pyomo.base import Var
 
        self.warm_start_file_name = pyutilib.services.TempfileManager.create_tempfile(suffix = '.cplex.mst')
 
@@ -108,7 +109,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
 
        # currently not populated.
        header_element = doc.createElement("header")
-       # currently not populated.       
+       # currently not populated.
        quality_element = doc.createElement("quality")
        # definitely populated!
        variables_element = doc.createElement("variables")
@@ -150,19 +151,18 @@ class CPLEX(ILMLicensedSystemCallSolver):
        # then we don't have an instance => the solver is being applied
        # to a file.
 
-       self.warm_start_solve = False               
-       if "warmstart" in kwds:
-          self.warm_start_solve = kwds["warmstart"]
-          del kwds["warmstart"]
+       self.warm_start_solve = kwds.pop( 'warmstart', False )
 
        if (len(args) > 0) and (isinstance(args[0],basestring) is False):
 
           # write the warm-start file - currently only supports MIPs.
-          # we only know how to deal with a single problem instance.       
+          # we only know how to deal with a single problem instance.
           if self.warm_start_solve is True:
 
              if len(args) != 1:
-                raise ValueError, "CPLEX _presolve method can only handle a single problem instance - "+str(len(args))+" were supplied"                  
+                msg = "CPLEX _presolve method can only handle a single "      \
+                      "problem instance - %s were supplied"
+                raise ValueError, msg % len(args)
 
              if self._hasIntegerVariables(args[0]) is True:
                 start_time = time.time()
@@ -170,7 +170,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
                 end_time = time.time()
                 if self._report_timing is True:
                    print "Warm start write time="+str(end_time-start_time)+" seconds"
-          
+
        # let the base class handle any remaining keywords/actions.
        ILMLicensedSystemCallSolver._presolve(self, *args, **kwds)
 
@@ -211,11 +211,11 @@ class CPLEX(ILMLicensedSystemCallSolver):
         cplex_script_file.write("set logfile "+self.log_file+"\n")
         if self._timelimit is not None and self._timelimit > 0.0:
             cplex_script_file.write("set timelimit "+`self._timelimit`+"\n")
-        if (self.mipgap is not None) and (self.mipgap > 0.0):
-            cplex_script_file.write("set mip tolerances mipgap "+`self.mipgap`+"\n")            
+        if (self.options.mipgap is not None) and (self.options.mipgap > 0.0):
+            cplex_script_file.write("set mip tolerances mipgap "+`self.options.mipgap`+"\n")
         for key in self.options:
-                if key in ['relax_integrality']:
-                    pass
+                if key == 'relax_integrality' or key == 'mipgap':
+                    continue
                 elif isinstance(self.options[key],basestring) and ' ' in self.options[key]:
                     opt = " ".join(key.split('_'))+" "+str(self.options[key])
                 else:
@@ -229,7 +229,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
 
         if 'relax_integrality' in self.options:
             cplex_script_file.write("change problem lp\n")
-            
+
         cplex_script_file.write("display problem stats\n")
         cplex_script_file.write("optimize\n")
         cplex_script_file.write("write " + self.soln_file+"\n")
@@ -267,7 +267,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
         # It is generally useful to know the CPLEX version number for logfile parsing.
         #
         cplex_version = None
-        
+
         #
         # Parse logfile lines
         #
@@ -293,7 +293,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
             elif len(tokens) >= 4 and tokens[0] == "Linear" and tokens[1] == "constraints":
                 results.problem.number_of_constraints = eval(tokens[3])
             elif len(tokens) >= 3 and tokens[0] == "Nonzeros":
-                if results.problem.number_of_nonzeros is None: # CPLEX 11.2 and subsequent has two Nonzeros sections.                
+                if results.problem.number_of_nonzeros is None: # CPLEX 11.2 and subsequent has two Nonzeros sections.
                     results.problem.number_of_nonzeros = eval(tokens[2])
             elif len(tokens) >= 5 and tokens[4] == "MINIMIZE":
                 results.problem.sense = ProblemSense.minimize
@@ -324,16 +324,16 @@ class CPLEX(ILMLicensedSystemCallSolver):
                 if results.solver.status == SolverStatus.error:
                    results.solver.status = SolverStatus.warning
                 else:
-                   results.solver.status = SolverStatus.ok                
+                   results.solver.status = SolverStatus.ok
                 results.solver.termination_condition = TerminationCondition.optimal
-                results.solver.termination_message = ' '.join(tokens)                
+                results.solver.termination_message = ' '.join(tokens)
             elif len(tokens) >= 3 and tokens[0] == "Presolve" and tokens[2] == "Infeasible.":
                 # if CPLEX has previously printed an error message, reduce it to a warning -
                 # there is a strong indication it recovered, but we can't be sure.
                 if results.solver.status == SolverStatus.error:
                    results.solver.status = SolverStatus.warning
                 else:
-                   results.solver.status = SolverStatus.ok                
+                   results.solver.status = SolverStatus.ok
                 results.solver.termination_condition = TerminationCondition.infeasible
                 results.solver.termination_message = ' '.join(tokens)
             elif len(tokens) >= 5 and tokens[0] == "Presolve" and tokens[2] == "Unbounded" and tokens[4] == "infeasible.":
@@ -342,7 +342,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
                 if results.solver.status == SolverStatus.error:
                    results.solver.status = SolverStatus.warning
                 else:
-                   results.solver.status = SolverStatus.ok                
+                   results.solver.status = SolverStatus.ok
                 # It isn't clear whether we can determine if the problem is unbounded from
                 # CPLEX's output.
                 results.solver.termination_condition = TerminationCondition.unbounded
@@ -357,9 +357,9 @@ class CPLEX(ILMLicensedSystemCallSolver):
     def process_soln_file(self,results):
 
         # the only suffixes that we extract from CPLEX are
-        # constraint duals, constraint slacks, and variable 
-        # reduced-costs. scan through the solver suffix list 
-        # and throw an exception if the user has specified 
+        # constraint duals, constraint slacks, and variable
+        # reduced-costs. scan through the solver suffix list
+        # and throw an exception if the user has specified
         # any others.
         extract_duals = False
         extract_slacks = False
@@ -370,20 +370,20 @@ class CPLEX(ILMLicensedSystemCallSolver):
                 extract_duals = True
                 flag=True
            if re.match(suffix,"slack"):
-                extract_slacks = True              
+                extract_slacks = True
                 flag=True
            if re.match(suffix,"rc"):
                 extract_reduced_costs = True
                 flag=True
            if not flag:
-              raise RuntimeError,"***CPLEX solver plugin cannot extract solution suffix="+suffix
+              raise RuntimeError,"***The CPLEX solver plugin cannot extract solution suffix="+suffix
 
         lp_solution = False
         if not os.path.exists(self.soln_file):
            return
 
         soln = Solution()
-        soln.objective['f'].value=None
+        soln.objective['__default_objective__'].value=None
         INPUT = open(self.soln_file,"r")
         results.problem.number_of_objectives=1
         mip_problem=False
@@ -474,21 +474,21 @@ class CPLEX(ILMLicensedSystemCallSolver):
                             results.problem.sense = ProblemSense.minimize
                     break
                 tINPUT.close()
-                
+
             elif tokens[0].startswith("objectiveValue"):
                 objective_value = (string.strip(tokens[0].split('=')[1])).lstrip("\"").rstrip("\"")
-                soln.objective['f'].value = eval(objective_value)
+                soln.objective['__default_objective__'].value = eval(objective_value)
             elif tokens[0].startswith("solutionStatusString"):
                 solution_status = (string.strip(" ".join(tokens).split('=')[1])).lstrip("\"").rstrip("\"")
                 if solution_status in ["optimal", "integer optimal solution", "integer optimal, tolerance"]:
                     soln.status = SolutionStatus.optimal
                     soln.gap = 0.0
                     if results.problem.sense == ProblemSense.minimize:
-                        results.problem.lower_bound = soln.objective['f'].value
+                        results.problem.lower_bound = soln.objective['__default_objective__'].value
                         if "upper_bound" in dir(results.problem):
                             del results.problem.upper_bound
                     else:
-                        results.problem.upper_bound = soln.objective['f'].value
+                        results.problem.upper_bound = soln.objective['__default_objective__'].value
                         if "lower_bound" in dir(results.problem):
                             del results.problem.lower_bound
                     mip_problem=True
@@ -501,7 +501,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
                     results.solver.statistics.branch_and_bound.number_of_created_subproblems=n
                     results.solver.statistics.branch_and_bound.number_of_bounded_subproblems=n
 
-                
+
         if not results.solver.status is SolverStatus.error:
             results.solution.insert(soln)
         INPUT.close()
@@ -529,7 +529,7 @@ class CPLEX(ILMLicensedSystemCallSolver):
               pass
 
         # let the base class deal with returning results.
-        return ILMLicensedSystemCallSolver._postsolve(self)            
+        return ILMLicensedSystemCallSolver._postsolve(self)
 
 
 class MockCPLEX(CPLEX,mockmip.MockMIP):
