@@ -12,8 +12,6 @@
 import os
 import re
 
-from coopr.pyomo import *
-
 from coopr.opt.base import *
 from coopr.opt.results import *
 from coopr.opt.solver import *
@@ -29,9 +27,6 @@ import xml.dom.minidom
 
 import time
 
-# WEH - I'm not quite sure how we want to disable this logic if the CPLEX 
-#       import fails.  Ideally, the plugins wouldn't get registered.  Perhaps
-#       we should explicitly disable them???
 try:
     import cplex
     from cplex.exceptions import CplexError
@@ -84,7 +79,7 @@ class CPLEXDirect(OptSolver):
 
                return True
 
-       return False        
+       return False
 
     #
     # TBD
@@ -93,7 +88,7 @@ class CPLEXDirect(OptSolver):
 
         from coopr.pyomo.expr import is_constant
         from coopr.pyomo.base import expr
-        
+
         if isinstance(exp, expr._IdentityExpression):
            return self._evaluate_bound(exp._args[0])
         elif exp.is_constant():
@@ -117,7 +112,7 @@ class CPLEXDirect(OptSolver):
        for variable_hash, coefficient in expression[1].iteritems():
 
           variable_hash_iter = variable_hash.iterkeys()
-          variable_name = hash_to_variable_map[variable_hash_iter.next()].label 
+          variable_name = hash_to_variable_map[variable_hash_iter.next()].label
 
           if as_pairs is True:
              pairs.append((variable_name, coefficient))
@@ -133,9 +128,9 @@ class CPLEXDirect(OptSolver):
           pairs.append((1, offset))
           return pairs, 0.0
        else:
-          expr = cplex.SparsePair(ind=variables, val=coefficients)           
+          expr = cplex.SparsePair(ind=variables, val=coefficients)
           return expr, offset
-   
+
     #
     # method to populate the CPLEX problem instance (interface) from the supplied Pyomo problem instance.
     #
@@ -143,7 +138,7 @@ class CPLEXDirect(OptSolver):
 
        from coopr.pyomo.base import Var, VarStatus, Objective, Constraint, IntegerSet, BooleanSet
        from coopr.pyomo.base.numtypes import minimize, maximize
-       from coopr.pyomo.expr import is_constant       
+       from coopr.pyomo.expr import is_constant
 
        # TBD
        cplex_instance = None
@@ -176,7 +171,7 @@ class CPLEXDirect(OptSolver):
              else:
                 var_lbs.append(var[ndx].lb())
              if var[ndx].ub is None:
-                var_ubs.append(cplex.infinity)                 
+                var_ubs.append(cplex.infinity)
              else:
                 var_ubs.append(var[ndx].ub())
              if isinstance(var.domain, IntegerSet):
@@ -197,10 +192,10 @@ class CPLEXDirect(OptSolver):
        rhss = []
        range_values = []
        names = []
-       
+
        active_constraints = pyomo_instance.active_components(Constraint)
        for key in active_constraints: # TBD: xfer to more efficient looping - use itervalues, for example.
-           
+
           if active_constraints[key].trivial:
              continue
 
@@ -218,7 +213,7 @@ class CPLEXDirect(OptSolver):
             if is_constant(constraint[cndx].repn):
                    continue
 
-            names.append(constraint[cndx].label)            
+            names.append(constraint[cndx].label)
 
             expr, offset = self._encode_constraint_body(constraint[cndx].repn)
 
@@ -231,7 +226,7 @@ class CPLEXDirect(OptSolver):
                 bound = self._evaluate_bound(bound_expr) - offset
                 rhss.append(bound)
                 range_values.append(0.0)
-                
+
             elif (constraint[cndx].lower is not None) and (constraint[cndx].upper is not None):
                 # ranged constraint.
                 senses.append('R')
@@ -240,21 +235,21 @@ class CPLEXDirect(OptSolver):
                 upper_bound_expr = constraint[cndx].upper # TBD - watch the offset - why not subtract?
                 upper_bound = self._evaluate_bound(upper_bound_expr)
                 rhss.append(lower_bound)
-                range_values.append(upper_bound-lower_bound)                
+                range_values.append(upper_bound-lower_bound)
 
             elif constraint[cndx].lower is not None:
                 senses.append('G')
                 bound_expr = constraint[cndx].lower
                 bound = self._evaluate_bound(bound_expr) - offset
                 rhss.append(bound)
-                range_values.append(0.0)                
+                range_values.append(0.0)
 
             else:
                 senses.append('L')
                 bound_expr = constraint[cndx].upper
                 bound = self._evaluate_bound(bound_expr) - offset
                 rhss.append(bound)
-                range_values.append(0.0)                
+                range_values.append(0.0)
 
        cplex_instance.linear_constraints.add(lin_expr=expressions, senses=senses, rhs=rhss, range_values=range_values, names=names)
 
@@ -262,12 +257,13 @@ class CPLEXDirect(OptSolver):
        active_objectives = pyomo_instance.active_components(Objective)
        the_objective = active_objectives[active_objectives.keys()[0]]
        if the_objective.sense == maximize:
-          cplex_instance.objective.set_sense(cplex_instance.objective.sense.maximize)     
+          cplex_instance.objective.set_sense(cplex_instance.objective.sense.maximize)
        else:
           cplex_instance.objective.set_sense(cplex_instance.objective.sense.minimize)
 
        objective_expression, junk = self._encode_constraint_body(the_objective[None].repn, True) # how to deal with indexed objectives?
        cplex_instance.objective.set_linear(objective_expression)
+       cplex_instance.objective.set_name(the_objective.name)
 
        # set the problem type based on the variable counts.
        if (num_integer_variables > 0) or (num_binary_variables > 0):
@@ -283,7 +279,7 @@ class CPLEXDirect(OptSolver):
     # cplex has a simple, easy-to-use warm-start capability.
     #
     def warm_start_capable(self):
-        
+
        return True
 
     #
@@ -292,7 +288,7 @@ class CPLEXDirect(OptSolver):
     def warm_start(self, instance):
 
        from coopr.pyomo.base import Var, VarStatus
-    
+
        # the iteration order is identical to that used in generating
        # the cplex instance, so all should be well.
        variable_names = []
@@ -310,40 +306,45 @@ class CPLEXDirect(OptSolver):
 
     # over-ride presolve to extract the warm-start keyword, if specified.
     def _presolve(self, *args, **kwds):
+       from coopr.pyomo.base.PyomoModel import Model
+
+       self.warm_start_solve = kwds.pop( 'warmstart', False )
+
+       model = args[ 0 ]
 
        # Step 1: extract the pyomo instance from the input arguments,
        #         cache it, and create the corresponding (as of now empty)
        #         CPLEX problem instance.
        if len(args) != 1:
-          raise ValueError, "The CPLEXDirect plugin method \"_presolve\" must be supplied a single problem instance - "+str(len(args))+" were supplied"
-       # TBD: I COULDN'T GET THE FOLLOWING TO WORK - THE TYPE WAS NEVER RECOGNIZED      
-#       if isinstance(args[0], coopr.pyomo.base.PyomoModel.Model) is False:
-#          raise ValueError, "The problem instance supplied to the CPLEXDirect plugin method \"_presolve\" must be of type Model"
+          msg = "The CPLEXDirect plugin method '_presolve' must be supplied " \
+                "a single problem instance - %s were supplied"
+          raise ValueError, msg % len(args)
+       if not isinstance(model, Model):
+          msg = "The problem instance supplied to the CPLEXDirect plugin "    \
+                "method '_presolve' must be of type 'Model'"
+          raise ValueError, msg
 
        # TBD-document.
-       self._populate_cplex_instance(args[0])
+       self._populate_cplex_instance(model)
 
        # if the first argument is a string (representing a filename),
        # then we don't have an instance => the solver is being applied
        # to a file.
 
-       self.warm_start_solve = False               
-       if "warmstart" in kwds:
-          self.warm_start_solve = kwds["warmstart"]
-          del kwds["warmstart"]
-
-       if (len(args) > 0) and (isinstance(args[0],basestring) is False):
+       if (len(args) > 0) and not isinstance(model,basestring):
 
           # write the warm-start file - currently only supports MIPs.
-          # we only know how to deal with a single problem instance.       
+          # we only know how to deal with a single problem instance.
           if self.warm_start_solve is True:
 
              if len(args) != 1:
-                raise ValueError, "CPLEX _presolve method can only handle a single problem instance - "+str(len(args))+" were supplied"                  
+                msg = "CPLEX _presolve method can only handle a single "      \
+                      "problem instance - %s were supplied"
+                raise ValueError, msg % len(args)
 
-             if self._hasIntegerVariables(args[0]) is True:
+             if self._hasIntegerVariables(model) is True:
                 start_time = time.time()
-                self.warm_start(args[0])
+                self.warm_start(model)
                 end_time = time.time()
                 if self._report_timing is True:
                    print "Warm start write time="+str(end_time-start_time)+" seconds"
@@ -354,8 +355,8 @@ class CPLEXDirect(OptSolver):
     def _apply_solver(self):
 
        # set up all user-specified parameters.
-       if (self.mipgap is not None) and (self.mipgap > 0.0):
-          self._active_cplex_instance.parameters.mip.tolerances.mipgap.set(self.mipgap)
+       if (self.options.mipgap is not None) and (self.options.mipgap > 0.0):
+          self._active_cplex_instance.parameters.mip.tolerances.mipgap.set(self.options.mipgap)
 
        # and kick off the solve.
        self._active_cplex_instance.set_results_stream(None)
@@ -391,11 +392,11 @@ class CPLEXDirect(OptSolver):
         cplex_script_file.write("set logfile "+self.log_file+"\n")
         if self._timelimit is not None and self._timelimit > 0.0:
             cplex_script_file.write("set timelimit "+`self._timelimit`+"\n")
-        if (self.mipgap is not None) and (self.mipgap > 0.0):
-            cplex_script_file.write("set mip tolerances mipgap "+`self.mipgap`+"\n")            
+        if (self.options.mipgap is not None) and (self.options.mipgap > 0.0):
+            cplex_script_file.write("set mip tolerances mipgap "+`self.options.mipgap`+"\n")
         for key in self.options:
-                if key in ['relax_integrality']:
-                    pass
+                if key == 'relax_integrality' or key == 'mipgap':
+                    continue
                 elif isinstance(self.options[key],basestring) and ' ' in self.options[key]:
                     opt = " ".join(key.split('_'))+" "+str(self.options[key])
                 else:
@@ -409,7 +410,7 @@ class CPLEXDirect(OptSolver):
 
         if 'relax_integrality' in self.options:
             cplex_script_file.write("change problem lp\n")
-            
+
         cplex_script_file.write("display problem stats\n")
         cplex_script_file.write("optimize\n")
         cplex_script_file.write("write " + self.soln_file+"\n")
@@ -448,7 +449,7 @@ class CPLEXDirect(OptSolver):
         # It is generally useful to know the CPLEX version number for logfile parsing.
         #
         cplex_version = None
-        
+
         #
         # Parse logfile lines
         #
@@ -474,7 +475,7 @@ class CPLEXDirect(OptSolver):
             elif len(tokens) >= 4 and tokens[0] == "Linear" and tokens[1] == "constraints":
                 results.problem.number_of_constraints = eval(tokens[3])
             elif len(tokens) >= 3 and tokens[0] == "Nonzeros":
-                if results.problem.number_of_nonzeros is None: # CPLEX 11.2 and subsequent has two Nonzeros sections.                
+                if results.problem.number_of_nonzeros is None: # CPLEX 11.2 and subsequent has two Nonzeros sections.
                     results.problem.number_of_nonzeros = eval(tokens[2])
             elif len(tokens) >= 5 and tokens[4] == "MINIMIZE":
                 results.problem.sense = ProblemSense.minimize
@@ -505,16 +506,16 @@ class CPLEXDirect(OptSolver):
                 if results.solver.status == SolverStatus.error:
                    results.solver.status = SolverStatus.warning
                 else:
-                   results.solver.status = SolverStatus.ok                
+                   results.solver.status = SolverStatus.ok
                 results.solver.termination_condition = TerminationCondition.optimal
-                results.solver.termination_message = ' '.join(tokens)                
+                results.solver.termination_message = ' '.join(tokens)
             elif len(tokens) >= 3 and tokens[0] == "Presolve" and tokens[2] == "Infeasible.":
                 # if CPLEX has previously printed an error message, reduce it to a warning -
                 # there is a strong indication it recovered, but we can't be sure.
                 if results.solver.status == SolverStatus.error:
                    results.solver.status = SolverStatus.warning
                 else:
-                   results.solver.status = SolverStatus.ok                
+                   results.solver.status = SolverStatus.ok
                 results.solver.termination_condition = TerminationCondition.infeasible
                 results.solver.termination_message = ' '.join(tokens)
             elif len(tokens) >= 5 and tokens[0] == "Presolve" and tokens[2] == "Unbounded" and tokens[4] == "infeasible.":
@@ -523,7 +524,7 @@ class CPLEXDirect(OptSolver):
                 if results.solver.status == SolverStatus.error:
                    results.solver.status = SolverStatus.warning
                 else:
-                   results.solver.status = SolverStatus.ok                
+                   results.solver.status = SolverStatus.ok
                 # It isn't clear whether we can determine if the problem is unbounded from
                 # CPLEX's output.
                 results.solver.termination_condition = TerminationCondition.unbounded
@@ -538,9 +539,9 @@ class CPLEXDirect(OptSolver):
     def process_soln_file(self,results):
 
         # the only suffixes that we extract from CPLEX are
-        # constraint duals, constraint slacks, and variable 
-        # reduced-costs. scan through the solver suffix list 
-        # and throw an exception if the user has specified 
+        # constraint duals, constraint slacks, and variable
+        # reduced-costs. scan through the solver suffix list
+        # and throw an exception if the user has specified
         # any others.
         extract_duals = False
         extract_slacks = False
@@ -551,7 +552,7 @@ class CPLEXDirect(OptSolver):
                 extract_duals = True
                 flag=True
            if re.match(suffix,"slack"):
-                extract_slacks = True              
+                extract_slacks = True
                 flag=True
            if re.match(suffix,"rc"):
                 extract_reduced_costs = True
@@ -564,7 +565,7 @@ class CPLEXDirect(OptSolver):
            return
 
         soln = Solution()
-        soln.objective['f'].value=None
+        soln.objective['__default_objective__'].value=None
         INPUT = open(self.soln_file,"r")
         results.problem.number_of_objectives=1
         mip_problem=False
@@ -655,21 +656,21 @@ class CPLEXDirect(OptSolver):
                             results.problem.sense = ProblemSense.minimize
                     break
                 tINPUT.close()
-                
+
             elif tokens[0].startswith("objectiveValue"):
                 objective_value = (string.strip(tokens[0].split('=')[1])).lstrip("\"").rstrip("\"")
-                soln.objective['f'].value = eval(objective_value)
+                soln.objective['__default_objective__'].value = eval(objective_value)
             elif tokens[0].startswith("solutionStatusString"):
                 solution_status = (string.strip(" ".join(tokens).split('=')[1])).lstrip("\"").rstrip("\"")
                 if solution_status in ["optimal", "integer optimal solution", "integer optimal, tolerance"]:
                     soln.status = SolutionStatus.optimal
                     soln.gap = 0.0
                     if results.problem.sense == ProblemSense.minimize:
-                        results.problem.lower_bound = soln.objective['f'].value
+                        results.problem.lower_bound = soln.objective['__default_objective__'].value
                         if "upper_bound" in dir(results.problem):
                             del results.problem.upper_bound
                     else:
-                        results.problem.upper_bound = soln.objective['f'].value
+                        results.problem.upper_bound = soln.objective['__default_objective__'].value
                         if "lower_bound" in dir(results.problem):
                             del results.problem.lower_bound
                     mip_problem=True
@@ -682,9 +683,10 @@ class CPLEXDirect(OptSolver):
                     results.solver.statistics.branch_and_bound.number_of_created_subproblems=n
                     results.solver.statistics.branch_and_bound.number_of_bounded_subproblems=n
 
-                
+
         if not results.solver.status is SolverStatus.error:
             results.solution.insert(soln)
+
         INPUT.close()
 
     def _postsolve(self):
@@ -700,7 +702,7 @@ class CPLEXDirect(OptSolver):
         results.problem.number_of_nonzeros = None
         results.problem.number_of_binary_variables = None
         results.problem.number_of_integer_variables = None
-        results.problem.number_of_continuous_variables = None        
+        results.problem.number_of_continuous_variables = None
         results.problem.number_of_objectives = 1
 
         results.solver.name = "CPLEX "+instance.get_version()
@@ -714,7 +716,7 @@ class CPLEXDirect(OptSolver):
         results.solver.termination_message = None
 
         soln = Solution()
-        soln.objective['f'].value = instance.solution.get_objective_value()
+        soln.objective['__default_objective__'].value = instance.solution.get_objective_value()
 
         num_variables = instance.variables.get_num()
         variable_names = instance.variables.get_names()
@@ -729,9 +731,12 @@ class CPLEXDirect(OptSolver):
               variable = soln.variable[variable_name]
               variable.value = variable_values[i]
            except:
-              variable.value = variable_values[i]           
+              variable.value = variable_values[i]
 
         results.solution.insert(soln)
+	#print type(instance),dir(instance.objective)
+	self._symbol_map = {}
+	self._symbol_map['__default_objective__'] = instance.objective.get_name()
 
         self.results = results
 
@@ -758,35 +763,7 @@ class CPLEXDirect(OptSolver):
               pass
 
         # let the base class deal with returning results.
-        return OptSolver._postsolve(self)            
-
-
-class MockCPLEXDirect(CPLEXDirect,mockmip.MockMIP):
-    """A Mock CPLEX solver used for testing
-    """
-
-    pyutilib.component.core.alias('_mock_cplexdirect')
-
-    def __init__(self, **kwds):
-        try:
-           CPLEXDirect.__init__(self, **kwds)
-        except pyutilib.common.ApplicationError: #pragma:nocover
-           pass                        #pragma:nocover
-        mockmip.MockMIP.__init__(self,"cplex")
-
-    def available(self, exception_flag=True):
-        return CPLEXDirect.available(self,exception_flag)
-
-    def create_command_line(self,executable,problem_files):
-        command = CPLEXDirect.create_command_line(self,executable,problem_files)
-        mockmip.MockMIP.create_command_line(self,executable,problem_files)
-        return command
-
-    def executable(self):
-        return mockmip.MockMIP.executable(self)
-
-    def _execute_command(self,cmd):
-        return mockmip.MockMIP._execute_command(self,cmd)
+        return OptSolver._postsolve(self)
 
 
 if cplex_import_available is False:
