@@ -96,8 +96,6 @@ class GLPK(SystemCallSolver):
         if self._timelimit is not None and self._timelimit > 0.0:
             cmd.append('--tmlim ' + str(self._timelimit))
 
-        if (self.mipgap is not None) and (self.mipgap > 0.0):
-            cmd.append('--mipgap ' + str(self.mipgap))
         cmd.append('--output ' + self.soln_file)
 
         if self._problem_format == ProblemFormat.cpxlp:
@@ -125,7 +123,6 @@ class GLPK(SystemCallSolver):
         # results.solver.statistics.branch_and_bound.
         #     number_of_bounded_subproblems=0
         soln = results.solution.add()
-        soln.objective['f'] = float('inf')
         #
         # Process logfile
         #
@@ -141,36 +138,18 @@ class GLPK(SystemCallSolver):
 
         for line in output.split("\n"):
             tokens = re.split('[ \t]+', line.strip())
-            if len(tokens) > 4 and tokens[1] == "objval":
-                soln.objective['f'] = tokens[3]
-            elif len(tokens) > 3 and tokens[0] == "Objective" and \
-                     tokens[1] == "value":
-                soln.objective['f'] = tokens[3]
-            elif len(tokens) > 4 and tokens[0] == "!" and \
-                     tokens[2] == "objval":
-                soln.objective['f'] = tokens[4]
-            elif len(tokens) > 4 and tokens[0] == "+" and \
-                     tokens[2] == "objval":
-                soln.objective['f'] = tokens[4]
-            elif len(tokens) > 4 and tokens[0] == "*" and \
-                     tokens[2] == "objval":
-                soln.objective['f'] = tokens[4]
-            elif len(tokens) > 4 and tokens[0] == "+" and \
+            if len(tokens) > 4 and tokens[0] == "+" and \
                      tokens[2] == "mip" and tokens[4] == "not":
-                soln.objective['f'] = "unknown"
                 results.problem.lower_bound = tokens[8]
             elif len(tokens) > 4 and tokens[0] == "+" and \
                      tokens[1] == "mip" and tokens[4] == "not":
-                soln.objective['f'] = "unknown"
                 results.problem.lower_bound = tokens[7]
             elif len(tokens) > 4 and tokens[0] == "+" and \
                      tokens[2] == "mip" and tokens[4] != "not":
-                soln.objective['f'] = tokens[4]
                 if tokens[6] != "tree":
                     results.problem.lower_bound = tokens[6]
             elif len(tokens) > 4 and tokens[0] == "+" and \
                      tokens[1] == "mip" and tokens[4] != "not":
-                soln.objective['f'] = tokens[3]
                 results.problem.lower_bound = tokens[5]
             elif len(tokens) == 6 and tokens[0] == "OPTIMAL" and \
                      tokens[1] == "SOLUTION" and tokens[5] == "PRESOLVER":
@@ -205,6 +184,10 @@ class GLPK(SystemCallSolver):
             elif len(tokens) > 2 and tokens[0] == "TIME" and \
                      tokens[2] == "EXCEEDED;":
                 soln.status = SolutionStatus.stoppedByLimit
+            if soln.status == SolutionStatus.optimal:
+                results.solver.termination_condition = TerminationCondition.optimal
+            elif soln.status == SolutionStatus.infeasible:
+                results.solver.termination_condition = TerminationCondition.infeasible
         if results.problem.upper_bound == "inf":
             results.problem.upper_bound = 'Infinity'
         if results.problem.lower_bound == "-inf":
@@ -221,33 +204,7 @@ class GLPK(SystemCallSolver):
             results.problem.lower_bound = str(tmp)
         except:
             pass
-        try:
-            val = soln.objective['f'].value
-            tmp = eval(val.strip())
-            soln.objective['f'] = str(tmp)
-        except:
-            pass
-        if soln.status is SolutionStatus.optimal:
-            soln.gap = 0.0
-        elif soln.status is SolutionStatus.stoppedByLimit:
-            soln.gap = "Infinity"  # until proven otherwise
-            if "lower_bound" in dir(results.problem):
-                if results.problem.lower_bound is "-Infinity":
-                    soln.gap = "Infinity"
-                elif not results.problem.lower_bound is None:
-                    if "upper_bound" not in dir(results.problem):
-                        gap = "Infinity"
-                    elif results.problem.upper_bound is None:
-                        gap = "Infinity"
-                    else:
-                        soln.gap = eval(soln.objective['f']) - \
-                                   eval(results.problem.lower_bound)
-            elif "upper_bound" in dir(results.problem):
-                if results.problem.upper_bound is "Infinity":
-                    soln.gap = "Infinity"
-                elif not results.problem.upper_bound is None:
-                    soln.gap = eval(results.problem.upper_bound) - \
-                               eval(soln.objective['f'])
+
         if results.solver.status is SolverStatus.error:
             results.solution.delete(0)
         return results
@@ -339,14 +296,14 @@ class GLPK(SystemCallSolver):
                             results.problem.sense = ProblemSense.minimize
                         else:
                             results.problem.sense = ProblemSense.maximize
-                        soln.objective['f'] = tokens[3]
+                        soln.objective[tokens[1]] = tokens[3]
                         if soln.status is SolutionStatus.optimal:
                             if tokens[4] == "(MINimum)":
-                                results.problem.lower_bound = soln.objective['f'].value
+                                results.problem.lower_bound = soln.objective[tokens[1]].value
                                 if "upper_bound" in dir(results.problem):
                                     del results.problem.upper_bound
                             else:
-                                results.problem.upper_bound = soln.objective['f'].value
+                                results.problem.upper_bound = soln.objective[tokens[1]].value
                                 if "lower_bound" in dir(results.problem):
                                     del results.problem.lower_bound
                         # the objective is the last entry in the problem section - move on to constraints.
@@ -579,6 +536,29 @@ class GLPK(SystemCallSolver):
         except Exception, msg:
             INPUT.close()
             raise RuntimeError, "Unexpected input encountered in GLPK solution file, yielding parse failure; line="+str(line)+"\nException: "+str(msg)
+        #
+        if soln.status is SolutionStatus.optimal:
+            soln.gap = 0.0
+        elif soln.status is SolutionStatus.stoppedByLimit:
+            soln.gap = "Infinity"  # until proven otherwise
+            if "lower_bound" in dir(results.problem):
+                if results.problem.lower_bound is "-Infinity":
+                    soln.gap = "Infinity"
+                elif not results.problem.lower_bound is None:
+                    if "upper_bound" not in dir(results.problem):
+                        gap = "Infinity"
+                    elif results.problem.upper_bound is None:
+                        gap = "Infinity"
+                    else:
+                        soln.gap = eval(soln.objective(0)) - \
+                                   eval(results.problem.lower_bound)
+            elif "upper_bound" in dir(results.problem):
+                if results.problem.upper_bound is "Infinity":
+                    soln.gap = "Infinity"
+                elif not results.problem.upper_bound is None:
+                    soln.gap = eval(results.problem.upper_bound) - \
+                               eval(soln.objective(0))
+
 
 class MockGLPK(GLPK,mockmip.MockMIP):
     """A Mock GLPK solver used for testing
