@@ -14,7 +14,6 @@ import re
 from coopr.opt.base import *
 from coopr.opt.results import *
 from coopr.opt.solver import *
-from coopr.pyomo.base.var import *
 import mockmip
 import pyutilib.services
 import pyutilib.common
@@ -76,23 +75,22 @@ class GUROBI(ILMLicensedSystemCallSolver):
     #
     def warm_start(self, instance):
 
+       from coopr.pyomo.base import Var, VarStatus
+
        self.warm_start_file_name = pyutilib.services.TempfileManager.create_tempfile(suffix = '.gurobi.mst')
 
        mst_file = open(self.warm_start_file_name,'w')
 
-       # for each variable, add a child to the variables element.
-       # both continuous and discrete are accepted (and required,
-       # depending on other options), according to the CPLEX manual.
        for variable in instance.active_components(Var).values():
 
-          for index in variable._varval.keys():
+          for varvalue in variable._varval.itervalues():
 
-             if (variable[index].status != VarStatus.unused) and (variable[index].value != None) and (variable[index].fixed == False):
+             if (varvalue.status != VarStatus.unused) and (varvalue.value != None) and (varvalue.fixed == False):
 
-                name = variable[index].label
+                name = varvalue.label
                 name = name.replace('[','(')
                 name = name.replace(']',')')
-                print >>mst_file, name, variable[index].value
+                print >>mst_file, name, varvalue.value
 
        mst_file.close()
 
@@ -182,7 +180,7 @@ class GUROBI(ILMLicensedSystemCallSolver):
         script += "from gurobipy import *\n"
         script += "sys.path.append('%s')\n" % os.path.dirname(__file__)
         script += "from GUROBI_RUN import *\n"
-        script += "gurobi_run%s\n" % str((problem_filename, warmstart_filename, solution_filename, self.mipgap, options_dict))
+        script += "gurobi_run%s\n" % str((problem_filename, warmstart_filename, solution_filename, self.options.mipgap, options_dict, self.suffixes))
         script += "quit()\n"
 
         self.gurobi_script_file_name = pyutilib.services.TempfileManager.create_tempfile(suffix = '.gurobi.script')
@@ -228,9 +226,11 @@ class GUROBI(ILMLicensedSystemCallSolver):
             line = line.lstrip()
             line = line.rstrip()
             tokens = line.split(":")
+            #print "LINE", line
             for i in range(0,len(tokens)):
                 tokens[i] = tokens[i].strip()
 
+            #print tokens
             if (tokens[0] == 'section'):
                 if (tokens[1] == 'problem'):
                     section = 'problem'
@@ -240,29 +240,54 @@ class GUROBI(ILMLicensedSystemCallSolver):
                     section = 'solver'
             else:
                 if (section == 'problem'):
-                    setattr(results.problem, tokens[0], tokens[1])
-                elif (section == 'solver'):
-                    if (tokens[0] == 'status'):
-                        results.solver.status = getattr(SolverStatus, tokens[1])
-                    elif (tokens[0] == 'termination_condition'):
-                        results.solver.termination_condition = getattr(TerminationCondition, tokens[1])
+                    if tokens[0] == 'sense':
+                        if tokens[1] == 'minimize':
+                            results.problem.sense = ProblemSense.minimize
+                        elif tokens[1] == 'maximize':
+                            results.problem.sense = ProblemSense.maximize
                     else:
-                        setattr(results.solver, tokens[0], tokens[1])
+                        try:
+                           val = eval(tokens[1])
+                        except:
+                           val = tokens[1]
+                        setattr(results.problem, tokens[0], val)
+                elif (section == 'solver'):
+                    try:
+                       val = eval(tokens[1])
+                    except:
+                       val = tokens[1]
+                    if (tokens[0] == 'status'):
+                        results.solver.status = getattr(SolverStatus, val)
+                    elif (tokens[0] == 'termination_condition'):
+                        results.solver.termination_condition = getattr(TerminationCondition, val)
+                    else:
+                        setattr(results.solver, tokens[0], val)
                 elif (section == 'solution'):
                     if (tokens[0] == 'status'):
                         soln.status = getattr(SolutionStatus, tokens[1])
+                    elif (tokens[0] == 'gap'):
+                        soln.gap = float(tokens[1])
                     elif (tokens[0] == 'objective'):
-                        soln.objective['f'].vale=eval(tokens[1])
-                    elif (tokens[0] == 'constraint'):
+                        soln.objective['__default_objective__'].value=float(tokens[1])
+                        if results.problem.sense == ProblemSense.minimize:
+                            results.problem.upper_bound = float(tokens[1])
+                        else:
+                            results.problem.lower_bound = float(tokens[1])
+                    elif (tokens[0] == 'constraintdual'):
                        if tokens[1] != "c_e_ONE_VAR_CONSTANT":
-                           soln_constraints[tokens[1]].dual = eval(tokens[2])
+                           soln_constraints[tokens[1]].dual = float(tokens[2])
+                    elif (tokens[0] == 'constraintslack'):
+                       if tokens[1] != "c_e_ONE_VAR_CONSTANT":
+                           soln_constraints[tokens[1]].slack = float(tokens[2])
                     elif (tokens[0] == 'variable'):
                        if tokens[1] != "ONE_VAR_CONSTANT":
-                         soln_variables[tokens[1]].value = eval(tokens[2])
+                         soln_variables[tokens[1]].value = float(tokens[2])
+                    elif (tokens[0] == 'variablerc'):
+                       if tokens[1] != "ONE_VAR_CONSTANT":
+                         soln_variables[tokens[1]].rc = float(tokens[2])
                     else:
                         setattr(soln, tokens[0], tokens[1])
 
-
         INPUT.close()
         results.solution.insert(soln)
 
