@@ -17,6 +17,7 @@ import pyutilib.services
 import pyutilib.common
 import pyutilib.common
 import pyutilib.component.core
+import pyutilib.misc
 import mockmip
 import os
 import copy
@@ -26,6 +27,8 @@ class PICO(SystemCallSolver):
     """The PICO LP/MIP solver
     """
 
+    pyutilib.component.core.alias('pico', doc='Shell interface to the PICO MIP solver')
+
     def __init__(self, **kwds):
         #
         # Call base constructor
@@ -41,6 +44,11 @@ class PICO(SystemCallSolver):
         self._valid_result_formats[ProblemFormat.nl] = [ResultsFormat.sol]
         self._valid_result_formats[ProblemFormat.mps] = [ResultsFormat.soln]
 
+        # Note: Undefined capabilities default to 'None'
+        self._capabilities = pyutilib.misc.Options()
+        self._capabilities.linear = True
+        self._capabilities.integer = True
+
     def executable(self):
         executable = pyutilib.services.registered_executable("PICO")
         if executable is None:
@@ -80,7 +88,7 @@ class PICO(SystemCallSolver):
         #
         # Define command line
         #
-        if (self.mipgap is not None):
+        if (self.options.mipgap is not None):
            raise ValueError, "The mipgap parameter is currently not being processed by PICO solver plugin"        
         env=copy.copy(os.environ)
         if self._problem_format is None or self._problem_format == ProblemFormat.nl:
@@ -89,6 +97,8 @@ class PICO(SystemCallSolver):
            else:
                 opts = ["debug=2"]
            for key in self.options:
+                if key == 'mipgap':
+                    continue
                 if isinstance(self.options[key],basestring) and ' ' in self.options[key]:
                     opts.append(key+"=\""+str(self.options[key])+"\"")
                 else:
@@ -101,6 +111,8 @@ class PICO(SystemCallSolver):
            else:
                 opt = " --debug 2"
            for key in self.options:
+                if key == 'mipgap':
+                    continue
                 if isinstance(self.options[key],basestring) and ' ' in self.options[key]:
                     opt += " --"+key+"=\""+str(self.options[key])+"\""
                 else:
@@ -119,7 +131,7 @@ class PICO(SystemCallSolver):
         #results.solver.statistics.branch_and_bound.number_of_created_subproblems=0
         #results.solver.statistics.branch_and_bound.number_of_bounded_subproblems=0
         soln = results.solution.add()
-        soln.objective['f'].value = None
+        soln.objective['__default_objective__'].value = None
         #
         # Process logfile
         #
@@ -134,36 +146,36 @@ class PICO(SystemCallSolver):
           if len(tokens) > 3 and tokens[0] == "ABORTED:":
              results.solver.status=SolverStatus.aborted
           elif len(tokens) == 5 and tokens[0] == "Final" and tokens[1] == "Solution:":
-             soln.objective['f'].value = tokens[4]
+             soln.objective['__default_objective__'].value = eval(tokens[4])
              soln.status = SolutionStatus.optimal
           elif len(tokens) == 3 and tokens[0] == "LP" and tokens[1] == "value=":
-             soln.objective['f'].value = tokens[2]
+             soln.objective['__default_objective__'].value = eval(tokens[2])
              soln.status=SolutionStatus.optimal
              if results.problem.sense == ProblemSense.minimize:
-                results.problem.lower_bound = tokens[2]
+                results.problem.lower_bound = eval(tokens[2])
              else:
-                results.problem.upper_bound = tokens[2]
+                results.problem.upper_bound = eval(tokens[2])
           elif len(tokens) == 2 and tokens[0] == "Bound:":
              if results.problem.sense == ProblemSense.minimize:
-                results.problem.lower_bound = tokens[1]
+                results.problem.lower_bound = eval(tokens[1])
              else:
-                results.problem.upper_bound = tokens[1]
+                results.problem.upper_bound = eval(tokens[1])
           elif len(tokens) == 3 and tokens[0] == "Created":
-             results.solver.statistics.branch_and_bound.number_of_created_subproblems = tokens[1]
+             results.solver.statistics.branch_and_bound.number_of_created_subproblems = eval(tokens[1])
           elif len(tokens) == 3 and tokens[0] == "Bounded":
-             results.solver.statistics.branch_and_bound.number_of_bounded_subproblems = tokens[1]
+             results.solver.statistics.branch_and_bound.number_of_bounded_subproblems = eval(tokens[1])
           elif len(tokens) == 2 and tokens[0] == "sys":
-             results.solver.system_time=tokens[1]
+             results.solver.system_time=eval(tokens[1])
           elif len(tokens) == 2 and tokens[0] == "user":
-             results.solver.user_time=tokens[1]
+             results.solver.user_time=eval(tokens[1])
           elif len(tokens) == 3 and tokens[0] == "Solving" and tokens[1] == "problem:":
              results.problem.name = tokens[2]
           elif len(tokens) == 4 and tokens[2] == "constraints:":
-             results.problem.number_of_constraints = tokens[3]
+             results.problem.number_of_constraints = eval(tokens[3])
           elif len(tokens) == 4 and tokens[2] == "variables:":
-             results.problem.number_of_variables = tokens[3]
+             results.problem.number_of_variables = eval(tokens[3])
           elif len(tokens) == 4 and tokens[2] == "nonzeros:":
-             results.problem.number_of_nonzeros = tokens[3]
+             results.problem.number_of_nonzeros = eval(tokens[3])
           elif len(tokens) == 3 and tokens[1] == "Sense:":
              if tokens[2] == "minimization":
                 results.problem.sense = ProblemSense.minimize
@@ -175,22 +187,40 @@ class PICO(SystemCallSolver):
         if soln.status is SolutionStatus.optimal:
            soln.gap=0.0
            if results.problem.sense == ProblemSense.minimize:
-                results.problem.lower_bound = soln.objective['f'].value
+                results.problem.lower_bound = soln.objective['__default_objective__'].value
                 if "upper_bound" in dir(results.problem):
                     del results.problem.upper_bound
            else:
-                results.problem.upper_bound = soln.objective['f'].value
+                results.problem.upper_bound = soln.objective['__default_objective__'].value
                 if "lower_bound" in dir(results.problem):
                     del results.problem.lower_bound
+
+        if soln.status == SolutionStatus.optimal:
+            results.solver.termination_condition = TerminationCondition.optimal
+        elif soln.status == SolutionStatus.infeasible:
+            results.solver.termination_condition = TerminationCondition.infeasible
+
         if results.solver.status is SolverStatus.error:
            results.solution.delete(0)
         return results
 
+
     def process_soln_file(self,results):
-        #print "HERE",self._results_format, self._results_format is ResultsFormat.sol, self.results_reader
+
         if self._results_format is ResultsFormat.sol:
            return
 
+        # the only suffixes that we extract from PICO are
+        # constraint duals. scan through the solver suffix 
+        # list and throw an exception if the user has 
+        # specified any others.
+        extract_duals = False
+        for suffix in self.suffixes:
+           if re.match(suffix,"dual"):
+              extract_duals = True
+           else:
+              raise RuntimeError,"***PICO solver plugin cannot extract solution suffix="+suffix
+
         #if os.path.exists(self.sol_file):
             #results_reader = ReaderFactory(ResultsFormat.sol)
             #results = results_reader(self.sol_file, results, results.solution(0))
@@ -204,6 +234,7 @@ class PICO(SystemCallSolver):
         flag=False
         INPUT = open(self.soln_file,"r")
         lp_flag=None
+        var_flag=True
         for line in INPUT:
             tokens = re.split('[ \t]+',line.strip())
             if len(tokens) == 0 or (len(tokens) == 1 and tokens[0]==''):
@@ -215,28 +246,40 @@ class PICO(SystemCallSolver):
                 lp_flag = (tokens[0] == "LP")
                 continue
             if tokens[0] == "Dual" and tokens[1] == "solution:":
+                var_flag=False
                 # It looks like we've just been processing primal
                 # variables.
                 for (var,val) in tmp:
+                    if var == 'ONE_VAR_CONSTANT':
+                        continue
                     soln.variable[var] = val
                 tmp=[]
                 continue
             if len(tokens) < 3:
                 print "ERROR", line,tokens
             tmp.append( (tokens[0],eval(tokens[2])) )
-        if lp_flag:
+        if var_flag:
             for (var,val) in tmp:
-                soln.constraint[var].dual = val
+                if var == 'ONE_VAR_CONSTANT':
+                    continue
+                soln.variable[var] = val
         else:
-            for (var,val) in tmp:
-                soln.variable[var] = val 
+            if (lp_flag is True) and (extract_duals is True):
+                for (var,val) in tmp:
+                    soln.constraint[var].dual = val
+            else:
+                for (var,val) in tmp:
+                    soln.constraint[var] = val 
         INPUT.close()
+        #print soln
 
 
 class MockPICO(PICO,mockmip.MockMIP):
     """A Mock PICO solver used for testing
     """
 
+    pyutilib.component.core.alias('_mock_pico')
+
     def __init__(self, **kwds):
         try:
            PICO.__init__(self,**kwds)
@@ -258,7 +301,3 @@ class MockPICO(PICO,mockmip.MockMIP):
     def _execute_command(self,cmd):
         return mockmip.MockMIP._execute_command(self,cmd)
 
-
-pyutilib.services.register_executable(name="pico")
-SolverRegistration("pico", PICO)
-SolverRegistration("_mock_pico", MockPICO)
