@@ -14,9 +14,12 @@ pyutilib.component.core.PluginGlobals.push_env( 'coopr.opt' )
 from PICO import PICO, MockPICO
 from CBCplugin import CBC, MockCBC
 from GLPK import GLPK, MockGLPK
+from glpk_file import GLPKLP
+from glpk_direct import GLPKDirect
 from CPLEX import CPLEX, MockCPLEX
-from CPLEXDirect import CPLEXDirect, MockCPLEXDirect
+from CPLEXDirect import CPLEXDirect
 from GUROBI import GUROBI
+from gurobi_direct import gurobi_direct
 from ASL import ASL, MockASL
 from ossolver import OSSolver
 #from NLWRITE import NLWRITE
