@@ -1,6 +1,6 @@
 from coopr.pyomo import *
 
-model = Model()
+model = AbstractModel()
 
 model.A = RangeSet(1,4)
 
