@@ -11,18 +11,18 @@ cooprdir = dirname(abspath(__file__))+os.sep+".."+os.sep+".."+os.sep
 currdir = dirname(abspath(__file__))+os.sep
 
 import re
-import unittest
 from nose.tools import nottest
 import coopr.plugins
 from coopr.opt import ProblemFormat, ConverterError
 import coopr
-import pyutilib.th
+import pyutilib.th as unittest
 import pyutilib.services
 import pyutilib.common
-import pyutilib.plugin.core
-import pyutilib.plugin.config
+import pyutilib.component.core
+import pyutilib.component.config
 import xml
 import filecmp
+import shutil
 
 
 class MockArg(object):
@@ -70,7 +70,7 @@ class MockArg4(MockArg):
         return (filename,None)
 
 
-class Test(pyutilib.th.TestCase):
+class Test(unittest.TestCase):
 
     def setUp(self):
         pyutilib.services.TempfileManager.tempdir = currdir
@@ -80,18 +80,18 @@ class Test(pyutilib.th.TestCase):
         #
         # Reset all options
         #
-        for ep in pyutilib.plugin.core.ExtensionPoint(pyutilib.plugin.config.IOption):
+        for ep in pyutilib.component.core.ExtensionPoint(pyutilib.component.config.IOption):
             ep.reset()
 
     def test_nl_nl1(self):
         """ Convert from NL to NL """
         ans = coopr.opt.convert_problem( ("test4.nl",), None, [ProblemFormat.nl])
-        self.failUnlessEqual(ans[0],("test4.nl",))
+        self.assertEqual(ans[0],("test4.nl",))
 
     def test_nl_nl2(self):
         """ Convert from NL to NL """
         ans = coopr.opt.convert_problem( ("test4.nl","tmp.nl"), None, [ProblemFormat.nl])
-        self.failUnlessEqual(ans[0],("test4.nl","tmp.nl"))
+        self.assertEqual(ans[0],("test4.nl","tmp.nl"))
 
     def test_nl_lp1(self):
         """ Convert from NL to LP """
@@ -105,8 +105,8 @@ class Test(pyutilib.th.TestCase):
            if not pyutilib.services.registered_executable("pico_convert") is None:
               self.fail("Unexpected ConverterError - pico_convert is enabled but not available: '%s'" % str(err))
            return
-        self.failUnlessEqual(ans[0][0][-15:],"pico_convert.lp")
-        self.failUnlessFileEqualsBaseline(ans[0][0], currdir+"test1_convert.lp")
+        self.assertEqual(ans[0][0][-15:],"pico_convert.lp")
+        self.assertFileEqualsBaseline(ans[0][0], currdir+"test1_convert.lp")
 
     def test_mod_lp1(self):
         """ Convert from MOD to LP """
@@ -120,8 +120,8 @@ class Test(pyutilib.th.TestCase):
            if not pyutilib.services.registered_executable("glpsol") is None:
               self.fail("Unexpected ConverterError - glpsol is enabled but not available: '%s'" % str(err))
            return
-        self.failUnlessEqual(ans[0],("glpsol.lp",))
-        self.failUnlessFileEqualsBaseline(ans[0][0], currdir+"test2_convert.lp")
+        self.assertEqual(ans[0],("glpsol.lp",))
+        self.assertFileEqualsBaseline(ans[0][0], currdir+"test2_convert.lp")
 
     def test_mod_lp2(self):
         """ Convert from MOD+DAT to LP """
@@ -135,14 +135,49 @@ class Test(pyutilib.th.TestCase):
            if not pyutilib.services.registered_executable("glpsol") is None:
               self.fail("Unexpected ConverterError - glpsol is enabled but not available: '%s'" % str(err))
            return
-        self.failUnlessEqual(ans[0],("glpsol.lp",))
-        self.failUnlessFileEqualsBaseline(ans[0][0], currdir+"test3_convert.lp")
+        self.assertEqual(ans[0],("glpsol.lp",))
+        self.assertFileEqualsBaseline(ans[0][0], currdir+"test3_convert.lp")
+
+    def test_mod_nl1(self):
+        """ Convert from MOD to NL """
+        try:
+           ans = coopr.opt.convert_problem( (currdir+"test3.mod",), None, [ProblemFormat.nl])
+        except pyutilib.common.ApplicationError, err:
+           if not pyutilib.services.registered_executable("ampl") is None:
+              self.fail("Unexpected ApplicationError - ampl is enabled but not available: '%s'" % str(err))
+           return
+        except ConverterError, err:
+           if not pyutilib.services.registered_executable("ampl") is None:
+              self.fail("Unexpected ConverterError - ampl is enabled but not available: '%s'" % str(err))
+           return
+        self.assertTrue(ans[0][0].endswith('.nl'))
+        #self.assertFileEqualsBinaryFile(ans[0][0], currdir+"test_mod_nl1.nl")
+
+    def test_mod_nl2(self):
+        """ Convert from MOD+DAT to NL """
+        try:
+           ans = coopr.opt.convert_problem( (currdir+"test5.mod",currdir+"test5.dat"), None, [ProblemFormat.nl])
+        except pyutilib.common.ApplicationError, err:
+           if not pyutilib.services.registered_executable("ampl") is None:
+              self.fail("Unexpected ApplicationError - ampl is enabled but not available: '%s'" % str(err))
+           return
+        except ConverterError, err:
+           if not pyutilib.services.registered_executable("ampl") is None:
+              self.fail("Unexpected ConverterError - ampl is enabled but not available: '%s'" % str(err))
+           return
+        self.assertTrue(ans[0][0].endswith('.nl'))
+        #self.assertFileEqualsBaseline(ans[0][0], currdir+"test_mod_nl2.nl")
 
     def test_mock_lp1(self):
         """ Convert from Pyomo to LP """
         arg=MockArg()
         ans = coopr.opt.convert_problem( (arg,ProblemFormat.cpxlp,arg), None, [ProblemFormat.cpxlp])
-        self.failIfEqual(re.match(".*tmp.*pyomo.lp$",ans[0][0]), None)
+        self.assertNotEqual(re.match(".*tmp.*pyomo.lp$",ans[0][0]), None)
+
+    def test_pyomo_lp1(self):
+        """ Convert from Pyomo to LP with file"""
+        ans = coopr.opt.convert_problem( (currdir+'model.py',ProblemFormat.cpxlp,), None, [ProblemFormat.cpxlp])
+        self.assertNotEqual(re.match(".*tmp.*pyomo.lp$",ans[0][0]), None)
 
     def test_mock_lp2(self):
         """ Convert from NL to LP """
@@ -154,7 +189,7 @@ class Test(pyutilib.th.TestCase):
               return
            else:
               self.fail("Expected ApplicationError because pico_convert is not available: '%s'" % str(err))
-        self.failUnlessEqual(ans[0][0][-15:],"pico_convert.lp")
+        self.assertEqual(ans[0][0][-15:],"pico_convert.lp")
         os.remove(ans[0][0])
 
     def test_mock_mps1(self):
@@ -167,14 +202,32 @@ class Test(pyutilib.th.TestCase):
                 return
            else:
                 self.fail("Expected ApplicationError because pico_convert is not available: '%s'" % str(err))
-        self.failUnlessEqual(ans[0][0][-16:],"pico_convert.mps")
+        self.assertEqual(ans[0][0][-16:],"pico_convert.mps")
+        os.remove(ans[0][0])
+
+    def test_pyomo_mps1(self):
+        """ Convert from Pyomo to MPS with file"""
+        try:
+           ans = coopr.opt.convert_problem( (currdir+'model.py',ProblemFormat.mps,), None, [ProblemFormat.mps])
+        except ConverterError, err:
+           if pyutilib.services.registered_executable("pico_convert") is None:
+                return
+           else:
+                self.fail("Expected ApplicationError because pico_convert is not available: '%s'" % str(err))
+        self.assertEqual(ans[0][0][-16:],"pico_convert.mps")
         os.remove(ans[0][0])
 
     def test_mock_nl1(self):
         """ Convert from Pyomo to NL """
         arg=MockArg4()
         ans = coopr.opt.convert_problem( (arg,ProblemFormat.nl,arg), None, [ProblemFormat.nl])
-        self.failIfEqual(re.match(".*tmp.*pyomo.nl$",ans[0][0]), None)
+        self.assertNotEqual(re.match(".*tmp.*pyomo.nl$",ans[0][0]), None)
+        os.remove(ans[0][0])
+
+    def test_pyomo_nl1(self):
+        """ Convert from Pyomo to NL with file"""
+        ans = coopr.opt.convert_problem( (currdir+'model.py',ProblemFormat.nl,), None, [ProblemFormat.nl])
+        self.assertNotEqual(re.match(".*tmp.*pyomo.nl$",ans[0][0]), None)
         os.remove(ans[0][0])
 
     def test_error1(self):
